@@ -47,34 +47,44 @@ typedef struct {
 	GDataEntryPrivate *priv;
 } GDataEntry;
 
-/**
+/*
  * GDataEntryClass:
  * @parent: the parent class
  * @get_xml: a function to build an XML representation of the #GDataEntry in its current state, appending it to the provided
  * #GString
+ * @parse_xml: a function to parse an XML representation of the #GDataEntry to set the properties of the @entry
  * @get_namespaces: a function to return a string containing the namespace declarations used by the entry when represented
  * in XML form
  *
  * The class structure for the #GDataEntry type.
+ */
+/**
+ * GDataEntryClass:
+ *
+ * All the fields in the #GDataEntryClass structure are private and should never be accessed directly.
  **/
 typedef struct {
+	/*< private >*/
 	GObjectClass parent;
 
 	void (*get_xml) (GDataEntry *self, GString *xml_string);
-	const gchar *(*get_namespaces) (GDataEntry *self);
+	gboolean (*parse_xml) (GDataEntry *self, xmlDoc *doc, xmlNode *node, GError **error);
+	void (*get_namespaces) (GDataEntry *self, GHashTable *namespaces);
 } GDataEntryClass;
 
-GType gdata_entry_get_type (void);
+GType gdata_entry_get_type (void) G_GNUC_CONST;
 
-GDataEntry *gdata_entry_new (void);
-GDataEntry *gdata_entry_new_from_xml (const gchar *xml, gint length, GError **error);
+GDataEntry *gdata_entry_new (const gchar *id) G_GNUC_WARN_UNUSED_RESULT;
+GDataEntry *gdata_entry_new_from_xml (const gchar *xml, gint length, GError **error) G_GNUC_WARN_UNUSED_RESULT;
 
 const gchar *gdata_entry_get_title (GDataEntry *self);
 void gdata_entry_set_title (GDataEntry *self, const gchar *title);
 const gchar *gdata_entry_get_id (GDataEntry *self);
+const gchar *gdata_entry_get_etag (GDataEntry *self);
 void gdata_entry_get_updated (GDataEntry *self, GTimeVal *updated);
 void gdata_entry_get_published (GDataEntry *self, GTimeVal *published);
 void gdata_entry_add_category (GDataEntry *self, GDataCategory *category);
+GList *gdata_entry_get_categories (GDataEntry *self);
 const gchar *gdata_entry_get_content (GDataEntry *self);
 void gdata_entry_set_content (GDataEntry *self, const gchar *content);
 void gdata_entry_add_link (GDataEntry *self, GDataLink *link);
@@ -82,7 +92,7 @@ GDataLink *gdata_entry_look_up_link (GDataEntry *self, const gchar *rel);
 void gdata_entry_add_author (GDataEntry *self, GDataAuthor *author);
 
 gboolean gdata_entry_is_inserted (GDataEntry *self);
-gchar *gdata_entry_get_xml (GDataEntry *self);
+gchar *gdata_entry_get_xml (GDataEntry *self) G_GNUC_WARN_UNUSED_RESULT;
 
 G_END_DECLS
 
