@@ -1,20 +1,20 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * GData Client
- * Copyright (C) Philip Withnall 2009 <philip@tecnocode.co.uk>
- * 
- * GData Client is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * Copyright (C) Philip Withnall 2008-2009 <philip@tecnocode.co.uk>
+ *
+ * GData Client is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * GData Client is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with GData Client.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with GData Client.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /**
@@ -29,8 +29,6 @@
  * online documentation</ulink>.
  **/
 
-/* TODO: Go through and see which pieces of API aren't allowed (ones which set server-side-only data) */
-
 #include <config.h>
 #include <glib.h>
 #include <glib/gi18n-lib.h>
@@ -49,7 +47,8 @@ static void gdata_youtube_video_finalize (GObject *object);
 static void gdata_youtube_video_get_property (GObject *object, guint property_id, GValue *value, GParamSpec *pspec);
 static void gdata_youtube_video_set_property (GObject *object, guint property_id, const GValue *value, GParamSpec *pspec);
 static void get_xml (GDataEntry *entry, GString *xml_string);
-static const gchar *get_namespaces (GDataEntry *entry);
+static gboolean parse_xml (GDataEntry *entry, xmlDoc *doc, xmlNode *node, GError **error);
+static void get_namespaces (GDataEntry *entry, GHashTable *namespaces);
 
 struct _GDataYouTubeVideoPrivate {
 	guint view_count;
@@ -119,6 +118,7 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	gobject_class->finalize = gdata_youtube_video_finalize;
 
 	entry_class->get_xml = get_xml;
+	entry_class->parse_xml = parse_xml;
 	entry_class->get_namespaces = get_namespaces;
 
 	/**
@@ -346,7 +346,7 @@ gdata_youtube_video_class_init (GDataYouTubeVideoClass *klass)
 	g_object_class_install_property (gobject_class, PROP_UPLOADED,
 				g_param_spec_boxed ("uploaded",
 					"Uploaded", "Specifies the time the video was originally uploaded to YouTube.",
-					G_TYPE_TIME_VAL,
+					GDATA_TYPE_G_TIME_VAL,
 					G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 
 	/**
@@ -537,15 +537,16 @@ gdata_youtube_video_set_property (GObject *object, guint property_id, const GVal
 
 /**
  * gdata_youtube_video_new:
+ * @id: the video's ID, or %NULL
  *
- * Creates a new #GDataYouTubeVideo with default properties.
+ * Creates a new #GDataYouTubeVideo with the given ID and default properties.
  *
  * Return value: a new #GDataYouTubeVideo; unref with g_object_unref()
  **/
 GDataYouTubeVideo *
-gdata_youtube_video_new (void)
+gdata_youtube_video_new (const gchar *id)
 {
-	return g_object_new (GDATA_TYPE_YOUTUBE_VIDEO, NULL);
+	return g_object_new (GDATA_TYPE_YOUTUBE_VIDEO, "id", id, NULL);
 }
 
 /**
@@ -564,66 +565,7 @@ gdata_youtube_video_new (void)
 GDataYouTubeVideo *
 gdata_youtube_video_new_from_xml (const gchar *xml, gint length, GError **error)
 {
-	xmlDoc *doc;
-	xmlNode *node;
-
-	g_return_val_if_fail (xml != NULL, NULL);
-
-	if (length == -1)
-		length = strlen (xml);
-
-	/* Parse the XML */
-	doc = xmlReadMemory (xml, length, "entry.xml", NULL, 0);
-	if (doc == NULL) {
-		xmlError *xml_error = xmlGetLastError ();
-		g_set_error (error, GDATA_PARSER_ERROR, GDATA_PARSER_ERROR_PARSING_STRING,
-			     _("Error parsing XML: %s"),
-			     xml_error->message);
-		return NULL;
-	}
-
-	/* Get the root element */
-	node = xmlDocGetRootElement (doc);
-	if (node == NULL) {
-		/* XML document's empty */
-		xmlFreeDoc (doc);
-		g_set_error (error, GDATA_PARSER_ERROR, GDATA_PARSER_ERROR_EMPTY_DOCUMENT,
-			     _("Error parsing XML: %s"),
-			     _("Empty document."));
-		return NULL;
-	}
-
-	if (xmlStrcmp (node->name, (xmlChar*) "entry") != 0) {
-		/* No <entry> element (required) */
-		xmlFreeDoc (doc);
-		gdata_parser_error_required_element_missing ("entry", "root", error);
-		return NULL;
-	}
-
-	return _gdata_youtube_video_new_from_xml_node (doc, node, error);
-}
-
-GDataYouTubeVideo *
-_gdata_youtube_video_new_from_xml_node (xmlDoc *doc, xmlNode *node, GError **error)
-{
-	GDataYouTubeVideo *video;
-
-	g_return_val_if_fail (doc != NULL, FALSE);
-	g_return_val_if_fail (node != NULL, FALSE);
-	g_return_val_if_fail (xmlStrcmp (node->name, (xmlChar*) "entry") == 0, FALSE);
-
-	video = gdata_youtube_video_new ();
-
-	node = node->xmlChildrenNode;
-	while (node != NULL) {
-		if (_gdata_youtube_video_parse_xml_node (video, doc, node, error) == FALSE) {
-			g_object_unref (video);
-			return NULL;
-		}
-		node = node->next;
-	}
-
-	return video;
+	return GDATA_YOUTUBE_VIDEO (_gdata_entry_new_from_xml (GDATA_TYPE_YOUTUBE_VIDEO, xml, length, error));
 }
 
 static gboolean
@@ -795,7 +737,7 @@ parse_media_group_xml_node (GDataYouTubeVideo *self, xmlDoc *doc, xmlNode *node,
 		g_object_notify (G_OBJECT (self), "restriction");
 	} else if (xmlStrcmp (node->name, (xmlChar*) "thumbnail") == 0) {
 		/* media:thumbnail */
-		xmlChar *uri, *width, *height, *time;
+		xmlChar *uri, *width, *height, *_time;
 		guint width_uint, height_uint;
 		gint time_int;
 		GDataMediaThumbnail *thumbnail;
@@ -814,19 +756,19 @@ parse_media_group_xml_node (GDataYouTubeVideo *self, xmlDoc *doc, xmlNode *node,
 		xmlFree (height);
 
 		/* Get and parse the time */
-		time = xmlGetProp (node, (xmlChar*) "time");
-		if (time == NULL) {
+		_time = xmlGetProp (node, (xmlChar*) "time");
+		if (_time == NULL) {
 			time_int = -1;
 		} else {
-			time_int = gdata_media_thumbnail_parse_time ((gchar*) time);
+			time_int = gdata_media_thumbnail_parse_time ((gchar*) _time);
 			if (time_int == -1) {
 				g_set_error (error, GDATA_SERVICE_ERROR, GDATA_SERVICE_ERROR_PROTOCOL_ERROR,
 					     _("The @time property (\"%s\") of a <media:thumbnail> could not be parsed."),
-					     (gchar*) time);
-				xmlFree (time);
+					     (gchar*) _time);
+				xmlFree (_time);
 				return FALSE;
 			}
-			xmlFree (time);
+			xmlFree (_time);
 		}
 
 		uri = xmlGetProp (node, (xmlChar*) "url");
@@ -875,10 +817,10 @@ parse_media_group_xml_node (GDataYouTubeVideo *self, xmlDoc *doc, xmlNode *node,
 	return TRUE;
 }
 
-gboolean
-_gdata_youtube_video_parse_xml_node (GDataYouTubeVideo *self, xmlDoc *doc, xmlNode *node, GError **error)
+static gboolean
+parse_xml (GDataEntry *entry, xmlDoc *doc, xmlNode *node, GError **error)
 {
-	GError *child_error = NULL;
+	GDataYouTubeVideo *self = GDATA_YOUTUBE_VIDEO (entry);
 
 	g_return_val_if_fail (GDATA_IS_YOUTUBE_VIDEO (self), FALSE);
 	g_return_val_if_fail (doc != NULL, FALSE);
@@ -1029,14 +971,8 @@ _gdata_youtube_video_parse_xml_node (GDataYouTubeVideo *self, xmlDoc *doc, xmlNo
 
 			child_node = child_node->next;
 		}
-	} else if (_gdata_entry_parse_xml_node (GDATA_ENTRY (self), doc, node, &child_error) == FALSE) {
-		if (g_error_matches (child_error, GDATA_PARSER_ERROR, GDATA_PARSER_ERROR_UNHANDLED_XML_ELEMENT) == TRUE) {
-			g_error_free (child_error);
-			gdata_parser_error_unhandled_element ((gchar*) node->ns->prefix, (gchar*) node->name, "entry", error);
-		} else {
-			g_propagate_error (error, child_error);
-		}
-
+	} else if (GDATA_ENTRY_CLASS (gdata_youtube_video_parent_class)->parse_xml (entry, doc, node, error) == FALSE) {
+		/* Error! */
 		return FALSE;
 	}
 
@@ -1129,14 +1065,14 @@ get_xml (GDataEntry *entry, GString *xml_string)
 
 	for (thumbnails = priv->thumbnails; thumbnails != NULL; thumbnails = thumbnails->next) {
 		GDataMediaThumbnail *thumbnail = (GDataMediaThumbnail*) thumbnails->data;
-		gchar *uri, *time;
+		gchar *uri, *_time;
 
 		uri = g_markup_escape_text (thumbnail->uri, -1);
-		time = gdata_media_thumbnail_build_time (thumbnail->time);
+		_time = gdata_media_thumbnail_build_time (thumbnail->time);
 		g_string_append_printf (xml_string, "<media:thumbnail url='%s' height='%u' width='%u' time='%s'/>",
-					uri, thumbnail->height, thumbnail->width, time);
+					uri, thumbnail->height, thumbnail->width, _time);
 		g_free (uri);
-		g_free (time);
+		g_free (_time);
 	}
 
 	if (priv->is_private == TRUE)
@@ -1163,10 +1099,14 @@ get_xml (GDataEntry *entry, GString *xml_string)
 	 */
 }
 
-static const gchar *
-get_namespaces (GDataEntry *entry)
+static void
+get_namespaces (GDataEntry *entry, GHashTable *namespaces)
 {
-	return "xmlns:media='http://search.yahoo.com/mrss/' xmlns:yt='http://gdata.youtube.com/schemas/2007'";
+	/* Chain up to the parent class */
+	GDATA_ENTRY_CLASS (gdata_youtube_video_parent_class)->get_namespaces (entry, namespaces);
+
+	g_hash_table_insert (namespaces, (gchar*) "media", (gchar*) "http://search.yahoo.com/mrss/");
+	g_hash_table_insert (namespaces, (gchar*) "yt", (gchar*) "http://gdata.youtube.com/schemas/2007");
 }
 
 /**
@@ -1586,7 +1526,7 @@ gdata_youtube_video_set_is_private (GDataYouTubeVideo *self, gboolean is_private
  * @uploaded: a #GTimeVal
  *
  * Gets the #GDataYouTubeVideo:uploaded property and puts it in @uploaded. If the property is unset,
- * both fields in the #GTimeVal will be set to 0.
+ * both fields in the #GTimeVal will be set to %0.
  **/
 void
 gdata_youtube_video_get_uploaded (GDataYouTubeVideo *self, GTimeVal *uploaded)
